==> haskell-byteable-0.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: byteable
version: 0.1.1
id: byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
key: byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-byteable
synopsis: Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes
    .
    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.
    .
    Usual definition of those types are of the form: newtype MyType = MyType ByteString
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Byteable
abi: 1033f0009ffea40431f55947ee171f57
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/byteable-0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-byteable
hs-libraries: HSbyteable-0.1.1-3VfNJqauCum9lD10cS8nmH
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html: /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byteable-0.1.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: byteable
version: 0.1.1
id: byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
key: byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-byteable
synopsis: Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes
    .
    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.
    .
    Usual definition of those types are of the form: newtype MyType = MyType ByteString
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Byteable
abi: d7caed3dfdc2cc9400ff9a46cbe7296d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/byteable-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-byteable
hs-libraries: HSbyteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html: /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
